pub struct AddressDef {
pub id: DefinitionId,
pub container_id: DefinitionId,
pub byte_offset: u32,
}Expand description
An address pointing to a specific byte offset within a container.
Addresses are used for divert targets, visit tracking, and any definition
that maps to a position within a container. A “primary” address has
byte_offset == 0 and the same id as its container_id, functioning
like the old Container tag. Intra-container addresses have non-zero
offsets and distinct IDs.
Fields
id: DefinitionIdcontainer_id: DefinitionIdbyte_offset: u32Trait Implementations
Sourceimpl Clone for AddressDef
impl Clone for AddressDef
Sourcefn clone(&self) -> AddressDef
fn clone(&self) -> AddressDef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AddressDef
Sourceimpl Debug for AddressDef
impl Debug for AddressDef
impl Eq for AddressDef
Sourceimpl PartialEq for AddressDef
impl PartialEq for AddressDef
Sourcefn eq(&self, other: &AddressDef) -> bool
fn eq(&self, other: &AddressDef) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AddressDef